@@ -48,9 +48,9 @@ class DownloadingFile:
         if wait_options is None:
             wait_options = DEFAULT_WAIT_OPTIONS
 
-        max_wait_minutues = self.get_max_wait_minutes(wait_options)
+        max_wait_minutes = self.get_max_wait_minutes(wait_options)
         filetype = DOWNLOADING_FILETYPE_DICT[job_type]
-        logger.info(f"{filetype}の更新処理が完了するまで、最大{max_wait_minutues}分間待ちます。job_id={job_id}")
+        logger.info(f"{filetype}の更新処理が完了するまで、最大{max_wait_minutes}分間待ちます。job_id={job_id}")
         result = self.service.wrapper.wait_for_completion(
             project_id,
             job_type=job_type,
@@ -58,7 +58,7 @@ class DownloadingFile:
             max_job_access=wait_options.max_tries,
         )
         if not result:
-            raise UpdatedFileForDownloadingError(f"{filetype}の更新処理が{max_wait_minutues}分以内に完了しない、または更新処理に失敗しました。")
+            raise UpdatedFileForDownloadingError(f"{filetype}の更新処理が{max_wait_minutes}分以内に完了しない、または更新処理に失敗しました。")
 
     async def download_annotation_zip_with_async(
         self, project_id: str, dest_path: str, is_latest: bool = False, wait_options: Optional[WaitOptions] = None
@@ -69,21 +69,33 @@ class DownloadingFile:
         return result
 
     def download_annotation_zip(
-        self, project_id: str, dest_path: str, is_latest: bool = False, wait_options: Optional[WaitOptions] = None
+        self,
+        project_id: str,
+        dest_path: str,
+        is_latest: bool = False,
+        wait_options: Optional[WaitOptions] = None,
+        should_download_full_annotation: bool = False,
     ):
-        logger.debug(f"アノテーションzipをダウンロードします。path={dest_path}")
+        """アノテーションZIPをダウンロードします。"""
+
+        def download_annotation_zip():
+            if should_download_full_annotation:
+                self.service.wrapper.download_full_annotation_archive(project_id, dest_path)
+            else:
+                self.service.wrapper.download_annotation_archive(project_id, dest_path)
+
         if is_latest:
             self.wait_until_updated_annotation_zip(project_id, wait_options)
-            self.service.wrapper.download_annotation_archive(project_id, dest_path)
+            download_annotation_zip()
 
         else:
             try:
-                self.service.wrapper.download_annotation_archive(project_id, dest_path)
+                download_annotation_zip()
             except requests.HTTPError as e:
                 if e.response.status_code == requests.codes.not_found:
                     logger.info(f"アノテーションzipが存在しなかったので、アノテーションzipファイルの更新処理を実行します。")
                     self.wait_until_updated_annotation_zip(project_id, wait_options)
-                    self.service.wrapper.download_annotation_archive(project_id, dest_path)
+                    download_annotation_zip()
                 else:
                     raise e
 
@@ -95,8 +107,10 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
-                logger.warning(f"{_get_annofab_error_message(e)}")
+                logger.warning(
+                    f"別のバックグラウンドジョブが既に実行されているので、アノテーションZIPの更新処理を実行できません。"
+                    f" :: error_message: {_get_annofab_error_message(e)}"
+                )
             else:
                 raise e
 
@@ -115,7 +129,6 @@ class DownloadingFile:
     def download_input_data_json(
         self, project_id: str, dest_path: str, is_latest: bool = False, wait_options: Optional[WaitOptions] = None
     ):
-        logger.debug(f"入力データ全件ファイルをダウンロードします。path={dest_path}")
         if is_latest:
             self.wait_until_updated_input_data_json(project_id, wait_options)
             self.service.wrapper.download_project_inputs_url(project_id, dest_path)
@@ -139,8 +152,9 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
-                logger.warning(f"{_get_annofab_error_message(e)}")
+                logger.warning(
+                    f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。 :: error_message: {_get_annofab_error_message(e)}"
+                )
             else:
                 raise e
 
@@ -159,7 +173,6 @@ class DownloadingFile:
     def download_task_json(
         self, project_id: str, dest_path: str, is_latest: bool = False, wait_options: Optional[WaitOptions] = None
     ):
-        logger.debug(f"タスク全件ファイルをダウンロードします。path={dest_path}")
         if is_latest:
             self.wait_until_updated_task_json(project_id, wait_options)
             self.service.wrapper.download_project_tasks_url(project_id, dest_path)
@@ -183,8 +196,9 @@ class DownloadingFile:
         except requests.HTTPError as e:
             # すでにジョブが進行中の場合は、無視する
             if e.response.status_code == requests.codes.conflict:
-                logger.warning(f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。")
-                logger.warning(f"{_get_annofab_error_message(e)}")
+                logger.warning(
+                    f"別のバックグラウンドジョブが既に実行されているので、更新処理を無視します。 :: error_message={_get_annofab_error_message(e)}"
+                )
             else:
                 raise e
 
@@ -213,12 +227,12 @@ class DownloadingFile:
             DownloadingFileNotFoundError:
         """
         try:
-            logger.debug(f"タスク履歴全件ファイルをダウンロードします。path={dest_path}")
             self.service.wrapper.download_project_task_histories_url(project_id, dest_path)
         except requests.HTTPError as e:
             if e.response.status_code == requests.codes.not_found:
-                logger.info(f"タスク履歴全件ファイルが存在しません。")
-                raise DownloadingFileNotFoundError("タスク履歴全件ファイルが存在しません。") from e
+                raise DownloadingFileNotFoundError(
+                    f"project_id='{project_id}'のプロジェクトに、タスク履歴全件ファイルが存在しないため、ダウンロードできませんでした。"
+                ) from e  # noqa: E501
             raise e
 
     def download_task_history_event_json(self, project_id: str, dest_path: str):
@@ -235,17 +249,17 @@ class DownloadingFile:
             DownloadingFileNotFoundError:
         """
         try:
-            logger.debug(f"タスク履歴イベント全件ファイルをダウンロードします。path={dest_path}")
             self.service.wrapper.download_project_task_history_events_url(project_id, dest_path)
         except requests.HTTPError as e:
             if e.response.status_code == requests.codes.not_found:
-                logger.info(f"タスク履歴イベント全件ファイルが存在しません。")
-                raise DownloadingFileNotFoundError("タスク履歴イベント全件ファイルが存在しません。") from e
+                raise DownloadingFileNotFoundError(
+                    f"project_id='{project_id}'のプロジェクトに、タスク履歴イベント全件ファイルが存在しないため、ダウンロードできませんでした。"
+                ) from e  # noqa: E501
             raise e
 
     async def download_task_history_event_json_with_async(self, project_id: str, dest_path: str):
         """
-        非同期で検査コメント全件ファイルをダウンロードする。
+        非同期でタスク履歴全件ファイルをダウンロードする。
 
         .. deprecated:: 0.21.1
 
@@ -263,9 +277,9 @@ class DownloadingFile:
             DownloadingFileNotFoundError:
         """
 
-        return self.download_inspection_json(project_id, dest_path=dest_path)
+        return self.download_inspection_comment_json(project_id, dest_path=dest_path)
 
-    def download_inspection_json(self, project_id: str, dest_path: str):
+    def download_inspection_comment_json(self, project_id: str, dest_path: str):
         """
         検査コメント全件ファイルをダウンロードする。
 
@@ -274,10 +288,37 @@ class DownloadingFile:
             DownloadingFileNotFoundError:
         """
         try:
-            logger.debug(f"検査コメント全件ファイルをダウンロードします。path={dest_path}")
             self.service.wrapper.download_project_inspections_url(project_id, dest_path)
         except requests.HTTPError as e:
             if e.response.status_code == requests.codes.not_found:
-                logger.info(f"検査コメント全件ファイルが存在しません。")
-                raise DownloadingFileNotFoundError("タスク履歴全件ファイルが存在しません。") from e
+                raise DownloadingFileNotFoundError(
+                    f"project_id='{project_id}'のプロジェクトに、検査コメント全件ファイルが存在しないため、ダウンロードできませんでした。"
+                ) from e  # noqa: E501
+            raise e
+
+    async def download_comment_json_with_async(self, project_id: str, dest_path: str):
+        """
+        非同期で検査コメント全件ファイルをダウンロードする。
+
+        Raises:
+            DownloadingFileNotFoundError:
+        """
+
+        return self.download_inspection_comment_json(project_id, dest_path=dest_path)
+
+    def download_comment_json(self, project_id: str, dest_path: str):
+        """
+        コメント全件ファイルをダウンロードする。
+
+
+        Raises:
+            DownloadingFileNotFoundError:
+        """
+        try:
+            self.service.wrapper.download_project_comments_url(project_id, dest_path)
+        except requests.HTTPError as e:
+            if e.response.status_code == requests.codes.not_found:
+                raise DownloadingFileNotFoundError(
+                    f"project_id='{project_id}'のプロジェクトに、コメント全件ファイルが存在しないため、ダウンロードできませんでした。"
+                ) from e  # noqa: E501
             raise e
