@@ -820,7 +820,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--type",
         type=str,
         choices=[e.value for e in CsvType],
-        default=CsvType.LABEL,
+        default=CsvType.LABEL.value,
         help="出力するCSVの種類を指定してください。 ``--format csv`` を指定したときのみ有効なオプションです。\n"
         "\n"
         "* label: ラベルごとにアノテーション数が記載されているCSV\n"
